@@ -1,14 +1,18 @@
 /** @file
 	Parser: request info class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_REQUEST_INFO_H
 #define PA_REQUEST_INFO_H
 
-#define IDENT_PA_REQUEST_INFO_H "$Id: pa_request_info.h,v 1.14 2017/02/07 22:00:36 moko Exp $"
+#define IDENT_PA_REQUEST_INFO_H "$Id: pa_request_info.h,v 1.17 2020/12/25 14:32:43 moko Exp $"
+
+// include
+
+#include "pa_config_includes.h"
 
 /// some information from web server
 class Request_info {
@@ -24,7 +28,6 @@ public:
 	const char* cookie;
 	
 	char** argv;
-	int args_skip;
 	bool mail_received;
 	//@}
 	//@{ these are filed by Request class itself: user's post data
@@ -55,6 +58,10 @@ public:
 		for(; *auri && *auri != '/'; auri++);
 		return auri;
 	}
+
+	Request_info() {
+		memset(this, 0, sizeof(*this)); // OK as Request_info is POD
+	}
 };
 
 #endif
