@@ -1,14 +1,14 @@
 /** @file
 	Parser: string class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_STRING_H
 #define PA_STRING_H
 
-#define IDENT_PA_STRING_H "$Id: pa_string.h,v 1.223 2017/02/07 22:00:36 moko Exp $"
+#define IDENT_PA_STRING_H "$Id: pa_string.h,v 1.228 2020/12/15 17:10:32 moko Exp $"
 
 // includes
 #include "pa_types.h"
@@ -16,7 +16,7 @@
 
 extern "C" { // cord's author forgot to do that
 #define CORD_NO_IO
-#include "cord.h"
+#include "../lib/cord/include/cord.h"
 
 #ifdef CORD_CAT_OPTIMIZATION
 #define CORD_cat(x, y) CORD_cat_optimized(x, y)
@@ -52,10 +52,10 @@ class VRegex;
 
 // generally useful
 
-int pa_atoi(const char* str, const String* problem_source=0);
 double pa_atod(const char* str, const String* problem_source=0);
-unsigned int pa_atoui(const char *str, int base, const String* problem_source=0);
-unsigned long long int pa_atoul(const char *str, int base, const String* problem_source=0);
+int pa_atoi(const char* str, int base=10, const String* problem_source=0);
+unsigned int pa_atoui(const char *str, int base=10, const String* problem_source=0);
+uint64_t pa_atoul(const char *str, int base=10, const String* problem_source=0);
 
 /// this is result of pos functions which mean that substr were not found
 #define STRING_NOT_FOUND ((size_t)-1)
@@ -90,24 +90,30 @@ public:
 
 		WARNING WARNING WARNING WARNING WARNING WARNING 
 	*/
-	enum Language {
-		L_UNSPECIFIED=0, ///< no real string has parts of this lange: it's just convinient to check when string's empty
-		// these two must go before others, there are checks for >L_AS_IS
-		L_CLEAN='0',	///< clean  WARNING: read above warning before changing
-		L_AS_IS='A',	///< leave all characters intact  WARNING: read above warning before changing
 
-		L_TAINTED='T',	///< tainted, untaint lang as assigned later 
+#if _MSC_VER >= 1900
+	/// required for VS2015+ to make sizeof(Languages::opt) == sizeof(CORD), will be 16 byte under x64 without it
+	enum Language : size_t {
+#else
+	enum Language {
+#endif
+		L_UNSPECIFIED=0,	///< no real string has parts of this lange: it's just convinient to check when string's empty
+		// these two must go before others, there are checks for >L_AS_IS
+		L_CLEAN='0',		///< clean  WARNING: read above warning before changing
+		L_AS_IS='A',		///< leave all characters intact  WARNING: read above warning before changing
+
+		L_TAINTED='T',		///< tainted, untaint lang as assigned later
 		// untaint langs. assigned by ^untaint[lang]{...}
 		L_FILE_SPEC='F',	///< file specification
 		L_HTTP_HEADER='h',	///< text in HTTP response header
 		L_MAIL_HEADER='m',	///< text in mail header
-		L_URI='U',			///< text in uri
-		L_SQL='Q',			///< ^table:sql body
-		L_JS='J',			///< JavaScript code
-		L_XML='X',			///< ^xdoc:create xml
-		L_HTML='H',			///< HTML code
+		L_URI='U',		///< text in uri
+		L_SQL='Q',		///< ^table:sql body
+		L_JS='J',		///< JavaScript code
+		L_XML='X',		///< ^xdoc:create xml
+		L_HTML='H',		///< HTML code
 		L_REGEX='R',		///< RegExp
-		L_JSON='S',			///< JSON code
+		L_JSON='S',		///< JSON code
 		L_HTTP_COOKIE='C',	///< cookies encoded as %uXXXX for compartibility with js functions encode/decode
 		L_PARSER_CODE='p',	///< ^process body
 		// READ WARNING ABOVE BEFORE ADDING ANYTHING
@@ -677,7 +683,7 @@ public:
 	const String& replace(const Dictionary& dict) const;
 	const String& trim(Trim_kind kind=TRIM_BOTH, const char* chars=0, Charset* source_charset=0) const;
 	double as_double() const { return pa_atod(cstr(), this); }
-	int as_int() const { return pa_atoi(cstr(), this); }
+	int as_int() const { return pa_atoi(cstr(), 0, this); }
 	bool as_bool() const { return as_int()!=0; }
 	const String& escape(Charset& source_charset) const;
 
