@@ -1,7 +1,7 @@
 /** @file
 	Parser: Stylesheet manager decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 
 	global sql driver manager, must be thread-safe
@@ -10,7 +10,7 @@
 #ifndef PA_STYLESHEET_MANAGER_H
 #define PA_STYLESHEET_MANAGER_H
 
-#define IDENT_PA_STYLESHEET_MANAGER_H "$Id: pa_stylesheet_manager.h,v 1.26 2017/02/07 22:00:37 moko Exp $"
+#define IDENT_PA_STYLESHEET_MANAGER_H "$Id: pa_stylesheet_manager.h,v 1.28 2020/12/15 17:10:32 moko Exp $"
 
 
 #include "pa_hash.h"
@@ -33,7 +33,7 @@ public:
 		check for disk update of "{file_spec}" or "{file_spec}.stamp",
 		if not updated return cached version[if any] otherwise load/compile/return
 	*/
-	Stylesheet_connection_ptr get_connection(String::Body file_spec);
+	Stylesheet_connection* get_connection(String::Body file_spec);
 
 private: // cache
 
