@@ -1,14 +1,14 @@
 /** @file
 	Parser: table class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_TABLE_H
 #define PA_TABLE_H
 
-#define IDENT_PA_TABLE_H "$Id: pa_table.h,v 1.70 2017/02/07 22:00:37 moko Exp $"
+#define IDENT_PA_TABLE_H "$Id: pa_table.h,v 1.72 2020/12/25 22:05:31 moko Exp $"
 
 #include "pa_types.h"
 #include "pa_hash.h"
@@ -32,9 +32,7 @@ class Table: public Array<ArrayString*> {
 public:
 	typedef ArrayString* columns_type;
 
-	Table(
-		columns_type acolumns,
-		size_t initial_rows=3);
+	Table(columns_type acolumns, size_t initial_rows=3);
 	Table(const Table& src, Action_options& options);
 
 	/// gets column names
@@ -58,6 +56,8 @@ public:
 	*/
 	int column_name2index(const String& column, bool bark) const;
 
+	void column_names_init();
+
 	/// @return item from @a column
 	const String* item(size_t column);
 
@@ -124,7 +124,6 @@ public:
 		return false;
 	}
 
-
 	bool locate(int column, const String& value, Action_options& options);
 	bool locate(const String& column, const String& value, Action_options& options);
 
