@@ -1,31 +1,37 @@
 /** @file
 	Parser: mutex & helpers decls.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_THREADS_H
 #define PA_THREADS_H
 
-#define IDENT_PA_THREADS_H "$Id: pa_threads.h,v 1.33 2017/02/07 22:00:37 moko Exp $"
+#define IDENT_PA_THREADS_H "$Id: pa_threads.h,v 1.37 2020/12/15 17:10:32 moko Exp $"
 
 #include "pa_config_includes.h"
 #include "pa_types.h"
 
-/// thread ID type
-typedef unsigned int pa_thread_t;
+#ifdef _MSC_VER
+#include <windows.h>
+#endif
 
 /// get caller thread ID
-pa_thread_t pa_get_thread_id();
+uint pa_get_thread_id();
 
 class AutoSYNCHRONIZED;
 
 /// simple semaphore object
 class Mutex {
 	friend class AutoSYNCHRONIZED;
-private:
-	uint handle;
+
+#ifdef _MSC_VER
+HANDLE handle;
+#else
+pthread_mutex_t handle;
+#endif
+
 public:
 	Mutex();
 	~Mutex();
@@ -34,14 +40,13 @@ private: // for AutoSYNCHRONIZED
 	void release();
 };
 
-extern const bool parser_multithreaded;
 extern Mutex global_mutex;
 
 /** 
 	Helper to ensure paired Mutex::acquire() and Mutex::release().
-
 	Use it with SYNCHRONIZED macro
 */
+
 class AutoSYNCHRONIZED {
 public:
 	AutoSYNCHRONIZED() { global_mutex.acquire(); }
