@@ -1,14 +1,14 @@
 /** @file
 	Parser: Value, Method, Junction .
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VALUE_H
 #define PA_VALUE_H
 
-#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.164 2017/02/16 12:16:34 moko Exp $"
+#define IDENT_PA_VALUE_H "$Id: pa_value.h,v 1.167 2020/12/15 17:10:38 moko Exp $"
 
 #include "pa_common.h"
 #include "pa_array.h"
@@ -34,7 +34,7 @@ class Table;
 struct XDocOutputOptions;
 typedef Array<Value*> ArrayValue;
 
-struct Json_options {
+struct Json_options : public PA_Allocated {
 	Request* r;
 	String::Body key;
 	HashStringValue* methods;
@@ -180,12 +180,8 @@ public: // Value
 	}
 #endif
 
-	/// indicator value meaning that put_element overwritten something
-	#define PUT_ELEMENT_REPLACED_ELEMENT reinterpret_cast<const VJunction*>(1)
-
 	/// store Value element under @a name
-	/// @returns putter method junction, or it can just report[PUT_ELEMENT_REPLACED_ELEMENT] 
-	/// that it replaced something in base fields 
+	/// @returns putter method junction, or 0
 	virtual const VJunction* put_element(const String& aname, Value* /*avalue*/) { 
 		// to prevent modification of system classes,
 		// created at system startup, and not having exception
@@ -230,12 +226,7 @@ public: // usage
 
 	/// throws exception specifying bark-reason and name() type() of problematic value
 	Value* bark(const char *reason, const String *problem_source=0) const {
-		//if(this) // removing warnings on unreachable code
-			throw Exception(PARSER_RUNTIME,
-				problem_source, 
-				reason, type());
-
-		//return 0;
+		throw Exception(PARSER_RUNTIME, problem_source, reason, type());
 	}
 
 };
