@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b console class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VCONSOLE_H
 #define PA_VCONSOLE_H
 
-#define IDENT_PA_VCONSOLE_H "$Id: pa_vconsole.h,v 1.25 2017/02/07 22:00:47 moko Exp $"
+#define IDENT_PA_VCONSOLE_H "$Id: pa_vconsole.h,v 1.27 2020/12/15 17:10:39 moko Exp $"
 
 // includes
 
@@ -55,12 +55,10 @@ public: // Value
 			puts(avalue->as_string().cstr());
 			fflush(stdout);
 
-			return PUT_ELEMENT_REPLACED_ELEMENT;
+			return 0;
 		}
 
-		throw Exception(PARSER_RUNTIME,
-			&aname,
-			"writing to invalid field");
+		throw Exception(PARSER_RUNTIME, &aname, "writing to invalid field");
 	}
 
 	bool was_used(){
