@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b double parser class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VDOUBLE_H
 #define PA_VDOUBLE_H
 
-#define IDENT_PA_VDOUBLE_H "$Id: pa_vdouble.h,v 1.67 2017/02/08 13:05:46 moko Exp $"
+#define IDENT_PA_VDOUBLE_H "$Id: pa_vdouble.h,v 1.71 2020/12/15 17:10:39 moko Exp $"
 
 // includes
 
@@ -28,8 +28,12 @@
 #define pa_finite(d) _finite(d)
 #else
 #define pa_isnan(d) isnan(d)
+#ifdef HAVE_ISFINITE
+#define pa_finite(d) isfinite(d)
+#else
 #define pa_finite(d) finite(d)
 #endif
+#endif
 
 // externs
 
