@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b env class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VENV_H
 #define PA_VENV_H
 
-#define IDENT_PA_VENV_H "$Id: pa_venv.h,v 1.42 2017/02/07 22:00:47 moko Exp $"
+#define IDENT_PA_VENV_H "$Id: pa_venv.h,v 1.44 2020/12/15 17:10:40 moko Exp $"
 
 // includes
 
@@ -25,6 +25,9 @@ public: // Value
 	// env: field
 	Value* get_element(const String& aname);
 
+	/// request: (key)=value
+	override const VJunction* put_element(const String& name, Value* value);
+
 public: // usage
 
 	VEnv(SAPI_Info& ainfo): 
