@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b form class decls.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VFORM_H
 #define PA_VFORM_H
 
-#define IDENT_PA_VFORM_H "$Id: pa_vform.h,v 1.65 2017/02/07 22:00:48 moko Exp $"
+#define IDENT_PA_VFORM_H "$Id: pa_vform.h,v 1.67 2020/12/15 17:10:40 moko Exp $"
 
 // includes
 
@@ -58,6 +58,9 @@ public: // Value
 	Value* get_element(const String& aname);
 	Charset* get_body_charset();
 
+	/// form: (field)=value
+	override const VJunction* put_element(const String& name, Value* value);
+
 public: // usage
 
 	VForm(Request_charsets& acharsets, Request_info& arequest_info);
