@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b regex class decls.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VREGEX_H
 #define PA_VREGEX_H
 
-#define IDENT_PA_VREGEX_H "$Id: pa_vregex.h,v 1.11 2017/02/07 22:00:50 moko Exp $"
+#define IDENT_PA_VREGEX_H "$Id: pa_vregex.h,v 1.14 2020/12/15 17:10:42 moko Exp $"
 
 // include
 
@@ -39,7 +39,7 @@ public: // Value
 	override VStateless_class *get_class() { return regex_class; }
 
 	/// VRegex: count
-	override int as_int() { return get_info_size(); }
+	override int as_int() { return (int)get_info_size(); }
 
 	/// VRegex: count
 	override double as_double() { return get_info_size(); }
@@ -85,6 +85,7 @@ public: // usage
 	}
 
 	void set(Charset& acharset, const String* aregex, const String* aoptions);
+	void set(VRegex& avregex);
 
 	void compile();
 
