@@ -1,14 +1,14 @@
 /** @file
 	Parser: stateless class decls.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VSTATELESS_CLASS_H
 #define PA_VSTATELESS_CLASS_H
 
-#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.91 2017/02/15 17:21:28 moko Exp $"
+#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.94 2021/01/02 23:01:11 moko Exp $"
 
 // include
 
@@ -88,9 +88,11 @@ public: // Value
 
 public: // usage
 
+	static bool gall_vars_local; // @conf[] $MAIN:LOCALS
+
 	VStateless_class(VStateless_class* amethoded_donor=0):
 		flocked(false),
-		fall_vars_local(false),
+		fall_vars_local(gall_vars_local),
 		fpartial(false),
 		fcall_type(Method::CT_ANY),
 		fbase(0),
@@ -162,6 +164,14 @@ public: // usage
 
 	/// @returns new value for current class, used in classes/ & VClass
 	virtual Value* create_new_value(Pool&) { return 0; }
+
+	const Method* get_element_method(const String &aname) {  // not get_method() to allow $aname[$method]
+		if(Value* value=get_element(aname))
+			if(Junction* junction=value->get_junction())
+				return junction->method;
+		return 0;
+	}
+
 };
 
 ///	Auto-object used for temporarily substituting/removing class method
