@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b xdoc parser class decl.
 
-	Copyright (c) 2001-2017 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2020 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VXDOC_H
 #define PA_VXDOC_H
 
-#define IDENT_PA_VXDOC_H "$Id: pa_vxdoc.h,v 1.58 2017/02/07 22:00:52 moko Exp $"
+#define IDENT_PA_VXDOC_H "$Id: pa_vxdoc.h,v 1.62 2020/12/15 17:10:44 moko Exp $"
 
 #include "classes.h"
 #include "pa_common.h"
@@ -24,7 +24,7 @@
 
 extern Methoded* xdoc_class;
 
-struct XDocOutputOptions {
+struct XDocOutputOptions : public PA_Allocated {
 	const String* method;       /* the output method */
 	const String* encoding;     /* encoding string */
 	const String* mediaType;    /* media-type string */
@@ -42,8 +42,6 @@ struct XDocOutputOptions {
 	void append(Request& r, HashStringValue* options, bool with_filename=false);
 };
 
-typedef struct _xsltStylesheet xsltStylesheet;
-
 /// value of type 'xdoc'. implemented with libxml & co
 class VXdoc: public VXnode {
 public: // Value
@@ -77,7 +75,7 @@ public: // VXNode
 
 public: // usage
 
-	VXdoc() : VXnode(*this), stylesheet(0), fcharsets(0), fdocument(0) {}
+	VXdoc() : VXnode(*this), fcharsets(0), fdocument(0) {}
 
 	VXdoc(Request_charsets& acharsets, xmlDoc& adocument) : VXnode(*this) {
 		set_xmldoc(acharsets, adocument);
@@ -89,18 +87,17 @@ public: // VXdoc
 		fcharsets=&acharsets;
 		fdocument=&adocument;
 		fdocument->_private=this;
-		stylesheet=0;
 	}
 
 	xmlDoc& get_xmldoc() {
 		if(!fdocument)
-			throw Exception(PARSER_RUNTIME, 0, "using unitialized xdoc object");
+			throw Exception(PARSER_RUNTIME, 0, "using uninitialized xdoc object");
 		return *fdocument;
 	}
 
 	Request_charsets& charsets() {
 		if(!fcharsets)
-			throw Exception(PARSER_RUNTIME, 0, "using unitialized xdoc object");
+			throw Exception(PARSER_RUNTIME, 0, "using uninitialized xdoc object");
 		return *fcharsets;
 	}
 
@@ -112,8 +109,6 @@ public:
 
 	XDocOutputOptions output_options;
 
-	xsltStylesheet *stylesheet;
-
 private:
 
 	Request_charsets* fcharsets;
